@@ -1,10 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Test::Kwalitee;
-# git description: v2.10-1-g2e614fa
-$Dist::Zilla::Plugin::Test::Kwalitee::VERSION = '2.11';
-# ABSTRACT: Release tests for kwalitee
+package Dist::Zilla::Plugin::Test::Kwalitee; # git description: v2.11-22-g5782daa
+# ABSTRACT: Author tests for kwalitee
 # KEYWORDS: plugin testing tests distribution kwalitee CPANTS quality lint errors critic
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
+
+our $VERSION = '2.12';
 
 use Moose;
 use Sub::Exporter::ForMethods 'method_installer'; # method_installer returns a sub.
@@ -24,7 +25,7 @@ has skiptest => (
   traits  => [ 'Array' ],
   default => sub { [] },
   handles => {
-    skiptest => 'elements',
+    skiptest => 'sort',
     push_skiptest => 'push'
   },
 );
@@ -41,8 +42,9 @@ around dump_config => sub
     my $config = $self->$orig;
 
     $config->{+__PACKAGE__} = {
-        skiptest => [ sort $self->skiptest ],
+        skiptest => [ $self->skiptest ],
         filename => $self->filename,
+        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
     return $config;
 };
@@ -66,8 +68,9 @@ sub gather_files {
 
   my $test_options = '';
 
-  if ( $self->skiptest > 0 ) {
-    my $skip = join ' ', map { "-$_" } sort $self->skiptest;
+  my @skiptests = $self->skiptest;
+  if (@skiptests > 0) {
+    my $skip = join ' ', map { "-$_" } @skiptests;
     $test_options = qq{ qw( $skip ) };
   }
 
@@ -95,17 +98,11 @@ sub gather_files {
 
 __PACKAGE__->meta->make_immutable;
 
-#pod =begin :prelude
-#pod
-#pod =for test_synopsis
-#pod 1;
-#pod __END__
-#pod
-#pod =end :prelude
+#pod =pod
 #pod
 #pod =head1 SYNOPSIS
 #pod
-#pod In C<dist.ini>:
+#pod In your F<dist.ini>:
 #pod
 #pod     [Test::Kwalitee]
 #pod     skiptest = use_strict ; Don't test for strictness.
@@ -150,18 +147,15 @@ __PACKAGE__->meta->make_immutable;
 
 =head1 NAME
 
-Dist::Zilla::Plugin::Test::Kwalitee - Release tests for kwalitee
+Dist::Zilla::Plugin::Test::Kwalitee - Author tests for kwalitee
 
 =head1 VERSION
 
-version 2.11
-
-=for test_synopsis 1;
-__END__
+version 2.12
 
 =head1 SYNOPSIS
 
-In C<dist.ini>:
+In your F<dist.ini>:
 
     [Test::Kwalitee]
     skiptest = use_strict ; Don't test for strictness.
@@ -218,12 +212,27 @@ L<Dist::Zilla::Plugin::Test::Kwalitee::Extra>
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Test-Kwalitee>
+(or L<bug-Dist-Zilla-Plugin-Test-Kwalitee@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Test-Kwalitee@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+irc://irc.perl.org/#distzilla.
+
 =head1 AUTHORS
 
 =over 4
 
 =item *
 
+Marcel Gruenauer <marcel@cpan.org>
+
+=item *
+
 Harley Pig <harleypig@gmail.com>
 
 =item *
@@ -232,10 +241,6 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =item *
 
-Marcel Gruenauer <marcel@cpan.org>
-
-=item *
-
 Kent Fredric <kentfredric@gmail.com>
 
 =item *
@@ -244,13 +249,6 @@ Karen Etheridge <ether@cpan.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2011 by Karen Etheridge.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 CONTRIBUTORS
 
 =for stopwords Marcel Gruenauer Mike Doherty Graham Knop
@@ -271,11 +269,18 @@ Graham Knop <haarg@haarg.org>
 
 =back
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Marcel Gruenauer.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
 __DATA__
 ___[ __TEST__ ]___
-# this test was generated with {{ ref($plugin) . ' ' . ($plugin->VERSION || '<self>') }}
+# this test was generated with {{ ref($plugin) . ' ' . $plugin->VERSION }}
 use strict;
 use warnings;
 use Test::More 0.88;
